==> 0.3.0.zip: grichelde/localisation/deDE.lua <==
local L = LibStub('AceLocale-3.0'):NewLocale('Grichelde', 'deDE')
if not L then return end

-- system messages
L.AddonName = "Grichelde"
L.AddonLoaded = "%s hilft Euch jetzt bei euren Sprachschwierigkeiten."
L.Addon_Detected_Misspelled = "Das Addon 'Misspelled' wurde erkannt und alle Nachrichten werden automatisch bereinigt."
L.Addon_Detected_WIM = "Das Addon 'WIM' wurde erkannt und alle Flüsternnachrichten aus IM-Fenster werden behandelt."

-- profiles
L.Profiles_Available = "Verf\195\188gbare Profile:"
L.Profiles_Created = "Neues Profil %s%s%s angelegt."
L.Profiles_Loaded = "Profil %s%s%s geladen."
L.Profiles_Refreshed = "Profil %s%s%s aktualisiert."
L.Profiles_Deleted = "Profil %s%s%s gel\195\182scht."
L.Profiles_Copied = "Einstellungen von Profil %s%s%s \195\188bernommen."
L.Profiles_Reset = "Profil %s%s%s zur\195\188ckgesetzt."
L.Profiles_Invalid = "Ung\195\188ltiges Profil %s%s%s!"
L.Profiles_DeleteError = "Das aktive Profil kann nicht gel\195\182scht werden!"

-- options
L.Options_Title = "%s Einstellungen"
L.Options_Enabled_Name = "Aktiv"
L.Options_Enabled_Desc = "Aktiviert %s"

L.Options_Channels_Group_Name = "Kan\195\164le"
L.Options_Channels_Group_Desc = "%s ist in folgenden Kan\195\164len aktiv."
L.Options_Channels_ChannelSay_Name = "Sagen"
L.Options_Channels_ChannelSay_Desc = "Aktiviert %s im Kanal \"Sagen\"."
L.Options_Channels_ChannelEmote_Name = "Emote"
L.Options_Channels_ChannelEmote_Desc = "Aktiviert %s im Kanal \"Emote\"."
L.Options_Channels_ChannelYell_Name = "Schreien"
L.Options_Channels_ChannelYell_Desc = "Aktiviert %s im Kanal \"Schreien\"."
L.Options_Channels_ChannelParty_Name = "Gruppe"
L.Options_Channels_ChannelParty_Desc = "Aktiviert %s im Kanal \"Gruppe\"."
L.Options_Channels_ChannelPartyLeader_Name = "Gruppenanf\195\188hrer"
L.Options_Channels_ChannelPartyLeader_Desc = "Aktiviert %s im Kanal \"Gruppenanf\195\188hrer\"."
L.Options_Channels_ChannelGuild_Name = "Gilde"
L.Options_Channels_ChannelGuild_Desc = "Aktiviert %s im Kanal \"Gilde\"."
L.Options_Channels_ChannelOfficer_Name = "Offiziere"
L.Options_Channels_ChannelOfficer_Desc = "Aktiviert %s im Kanal \"Offiziere\"."
L.Options_Channels_ChannelRaid_Name = "Schlachtzug"
L.Options_Channels_ChannelRaid_Desc = "Aktiviert %s im Kanal \"Schlachtzug\"."
L.Options_Channels_ChannelRaidLeader_Name = "Schlachtzugsanf\195\188hrer"
L.Options_Channels_ChannelRaidLeader_Desc = "Aktiviert %s im Kanal \"Schlachtzugsanf\195\188hrer\"."
L.Options_Channels_ChannelInstance_Name = "Instanz"
L.Options_Channels_ChannelInstance_Desc = "Aktiviert %s im Kanal \"Instanz\"."
L.Options_Channels_ChannelBattleground_Name = "Schlachtfeld"
L.Options_Channels_ChannelBattleground_Desc = "Aktiviert %s im Kanal \"Schlachtfeld\"."
L.Options_Channels_ChannelWhisper_Name = "Fl\195\188stern"
L.Options_Channels_ChannelWhisper_Desc = "Aktiviert %s im Kanal \"Fl\195\188stern\"."

L.Options_Replacements_Group_Name = "Ersetzungen"
L.Options_Replacements_Group_Desc = "Diese Vorkommen werden in den aktivierten Kan\195\164len ersetzt."
L.Options_Replacements_Add_Name = "Hinzu"
L.Options_Replacements_Add_Desc = "F\195\188gt eine neue Zuordnung hinzu."
L.Options_Replacements_DeleteAll_Name = "Alle L\195\182schen"
L.Options_Replacements_DeleteAll_Desc = "L\195\182scht alle Zuweisungen."

L.Options_Replacement_Group_Name = "Ersetzung"
L.Options_Replacement_Group_Desc = "Dieses Vorkommen wird in den aktivierten Kan\195\164len ersetzt."
L.Options_Replacement_SearchText_Name = "Suchtext:"
L.Options_Replacement_SearchText_Desc = "Dieser Text wird in der Chateingabe gesucht."
L.Options_Replacement_ReplaceText_Name = "Ersetzung:"
L.Options_Replacement_ReplaceText_Desc = "Jeder Suchtreffer wird mit diesem Text ersetzt."
L.Options_Replacement_CaseSensitive_Name = "Gro\195\159- und Kleinschreibung beachten"
L.Options_Replacement_CaseSensitive_Desc = "Groß\195\159buchstaben werden mit Gro\195\159buchstaben ersetzt."
L.Options_Replacement_Consolidate_Name = "Fa\195\159e aufeinanderfolgende Treffer zusammen"
L.Options_Replacement_Consolidate_Desc = "Wenn durch die Ersetzung die Zeichenfolge mehrfach hintereinander steht,|nfasse sie zu einem Vorkommen zusammen."
L.Options_Replacement_Delete_Name = "L\195\182schen"
L.Options_Replacement_Delete_Desc = "L\195\182scht diese Zuweisung."

==> 0.5.0.zip: grichelde/localisation/deDE.lua <==
local L = LibStub('AceLocale-3.0'):NewLocale('Grichelde', 'deDE')
if not L then return end

-- system messages
L.AddonName = "Grichelde"
L.VersionAbbr = "v"
L.AddonLoaded = "%s hilft Euch jetzt bei euren Sprachschwierigkeiten."
L.Addon_Detected_Misspelled = "Das Addon 'Misspelled' wurde erkannt und alle Nachrichten werden automatisch bereinigt."
L.Addon_Detected_WIM = "Das Addon 'WIM' wurde erkannt und alle Flüsternnachrichten aus IM-Fenster werden behandelt."

-- profiles
L.Profiles_Available = "Verf\195\188gbare Profile:"
L.Profiles_Created = "Neues Profil %s angelegt."
L.Profiles_Loaded = "Profil %s geladen."
L.Profiles_Refreshed = "Profil %s aktualisiert."
L.Profiles_Deleted = "Profil %s gel\195\182scht."
L.Profiles_Copied = "Einstellungen von Profil %s \195\188bernommen."
L.Profiles_Reset = "Profil %s zur\195\188ckgesetzt."
L.Profiles_Invalid = "Ung\195\188ltiges Profil %s!"
L.Profiles_DeleteError = "Das aktive Profil kann nicht gel\195\182scht werden!"

-- options
L.Options_Title = "%s Einstellungen"
L.Options_Enabled_Name = "Aktiv"
L.Options_Enabled_Desc = "Aktiviert %s"

L.Options_Channels_Group_Name = "Kan\195\164le"
L.Options_Channels_Group_Desc = "%s ist in folgenden Kan\195\164len aktiv."
L.Options_Channels_ChannelSay_Name = "Sagen"
L.Options_Channels_ChannelSay_Desc = "Aktiviert %s im Kanal \"Sagen\"."
L.Options_Channels_ChannelEmote_Name = "Emote"
L.Options_Channels_ChannelEmote_Desc = "Aktiviert %s im Kanal \"Emote\"."
L.Options_Channels_ChannelYell_Name = "Schreien"
L.Options_Channels_ChannelYell_Desc = "Aktiviert %s im Kanal \"Schreien\"."
L.Options_Channels_ChannelParty_Name = "Gruppe"
L.Options_Channels_ChannelParty_Desc = "Aktiviert %s im Kanal \"Gruppe\"."
L.Options_Channels_ChannelPartyLeader_Name = "Gruppenanf\195\188hrer"
L.Options_Channels_ChannelPartyLeader_Desc = "Aktiviert %s im Kanal \"Gruppenanf\195\188hrer\"."
L.Options_Channels_ChannelGuild_Name = "Gilde"
L.Options_Channels_ChannelGuild_Desc = "Aktiviert %s im Kanal \"Gilde\"."
L.Options_Channels_ChannelOfficer_Name = "Offiziere"
L.Options_Channels_ChannelOfficer_Desc = "Aktiviert %s im Kanal \"Offiziere\"."
L.Options_Channels_ChannelRaid_Name = "Schlachtzug"
L.Options_Channels_ChannelRaid_Desc = "Aktiviert %s im Kanal \"Schlachtzug\"."
L.Options_Channels_ChannelRaidLeader_Name = "Schlachtzugsanf\195\188hrer"
L.Options_Channels_ChannelRaidLeader_Desc = "Aktiviert %s im Kanal \"Schlachtzugsanf\195\188hrer\"."
L.Options_Channels_ChannelRaidWarning_Name = "Schlachtzugswarnung"
L.Options_Channels_ChannelRaidWarning_Desc = "Aktiviert %s im Kanal \"Schlachtzugswarnung."
L.Options_Channels_ChannelInstance_Name = "Instanz"
L.Options_Channels_ChannelInstance_Desc = "Aktiviert %s im Kanal \"Instanz\"."
L.Options_Channels_ChannelBattleground_Name = "Schlachtfeld"
L.Options_Channels_ChannelBattleground_Desc = "Aktiviert %s im Kanal \"Schlachtfeld\"."
L.Options_Channels_ChannelWhisper_Name = "Fl\195\188stern"
L.Options_Channels_ChannelWhisper_Desc = "Aktiviert %s im Kanal \"Fl\195\188stern\"."

L.Options_Replacements_Group_Name = "Ersetzungen"
L.Options_Replacements_Group_Desc = "Diese Vorkommen werden in den aktivierten Kan\195\164len ersetzt."
L.Options_Replacements_Add_Name = "Hinzu"
L.Options_Replacements_Add_Desc = "F\195\188gt eine neue Zuordnung hinzu."
L.Options_Replacements_DeleteAll_Name = "Alle L\195\182schen"
L.Options_Replacements_DeleteAll_Desc = "L\195\182scht alle Zuweisungen."
L.Options_Replacements_DeleteAll_ConfirmText="Wirklich ALLE Zuweisungen l\195\182schen?"

L.Options_Replacement_Group_Name = "%s => %s"
L.Options_Replacement_Group_Desc = "Dieses Vorkommen wird in den aktivierten Kan\195\164len ersetzt."
L.Options_Replacement_EmptyMapping = "(keine)"
L.Options_Replacement_SearchText_Name = "Suchtext:"
L.Options_Replacement_SearchText_Desc = "Dieser Text wird in der Chateingabe gesucht."
L.Options_Replacement_ReplaceText_Name = "Ersetzung:"
L.Options_Replacement_ReplaceText_Desc = "Jeder Suchtreffer wird mit diesem Text ersetzt."
L.Options_Replacement_CaseSensitive_Name = "Gro\195\159- und Kleinschreibung beachten"
L.Options_Replacement_CaseSensitive_Desc = "Groß\195\159buchstaben werden mit Gro\195\159buchstaben ersetzt."
L.Options_Replacement_Consolidate_Name = "Fa\195\159e aufeinanderfolgende Treffer zusammen"
L.Options_Replacement_Consolidate_Desc = "Wenn durch die Ersetzung die Zeichenfolge mehrfach hintereinander steht,|nfasse sie zu einem Vorkommen zusammen."
L.Options_Replacement_Delete_Name = "L\195\182schen"
L.Options_Replacement_Delete_Desc = "L\195\182scht diese Zuweisung."
L.Options_Replacements_Delete_ConfirmText="Diese Zuweisung l\195\182schen?"
